@@ -12,6 +12,8 @@ import pickle
 import os
 import webbrowser
 
+cwd = os.getcwd()
+
 app = Flask(__name__)
 
 
@@ -31,11 +33,11 @@ def add_header(r):
 @app.route('/menu')
 def index():
     html_code = "<style>a:hover{cursor:pointer;}</style><ul>"
-    for folder in [x[0] for x in os.walk(".")]:
+    for folder in [x[0] for x in os.walk(cwd)]:
         if folder != ".":
             try:
-                ft = folder.replace("\\","").replace(".","")
                 r = open(folder+"\\index.html")
+                ft = folder.split("\\")[-1].replace(".","")
                 html_code = html_code + f"""
                     <li><a onclick="urlc('interface/{ft}')" >{ft}</a></li>
                 """
@@ -55,11 +57,11 @@ def index():
     return html_code
 
 
-@app.route('/f/<path:folder>')
-def send_asset(folder):
+@app.route('/f/<path:path_file>')
+def send_asset(path_file):
     print("passed")
-    print(folder)
-    return open( folder, "r").read() 
+    print(path_file)
+    return open( path_file, "r").read() 
 
 
 @app.route('/input_data/<folder>', methods=["POST"])
@@ -70,12 +72,12 @@ def input_data(folder):
     print(data)
     
     # Save file
-    file = open(folder+"/input_data.pkl","wb")
+    file = open(cwd+"\\"+folder+"\\input_data.pkl","wb")
     pickle.dump(data,file)
     file.close()
     
     ts = str(datetime.timestamp(datetime.now()))
-    file = open(folder+"/lastuitime.txt","w")
+    file = open(cwd+"\\"+folder+"\\lastuitime.txt","w")
     file.write(ts)
     file.close()
     
@@ -86,15 +88,15 @@ def input_data(folder):
 def interface(folder):
     
     uid = request.url.split("?uid=")[-1]
-    html = send_asset(folder + "/index.html")
+    html = send_asset(cwd+"\\"+folder+"\\index.html")
     
     # Check if file exist
-    if os.path.exists(folder+"/input_data.pkl"):
-        file = open(folder+"/input_data.pkl","rb")
+    if os.path.exists(cwd+"\\"+folder+"\\input_data.pkl"):
+        file = open(cwd+"\\"+folder+"\\input_data.pkl","rb")
         data = pickle.load(file)
         if(int(data["uid"]) != int(uid)):
             # Check time
-            ti_c = os.path.getmtime(folder+"/input_data.pkl")
+            ti_c = os.path.getmtime(cwd+"\\"+folder+"\\input_data.pkl")
             print(datetime.timestamp(datetime.now()))
             print(ti_c)
             if (ti_c+10) > datetime.timestamp(datetime.now()):
